==> pyviz_comms-3.0.5.tar.gz: pyviz_comms-3.0.5/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 3.0.5

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.4...f122bf716c61db4ae38a1247a6d4bc745516f94e))

### Merged PRs

- Ensure comms can reconnect on page reload [#136](https://github.com/holoviz/pyviz_comms/pull/136) ([@philippjfr](https://github.com/philippjfr))
- ci: Update Github Actions version number [#135](https://github.com/holoviz/pyviz_comms/pull/135) ([@hoxbro](https://github.com/hoxbro))
- fix: Use get_ipython for \_in_ipython check [#134](https://github.com/holoviz/pyviz_comms/pull/134) ([@hoxbro](https://github.com/hoxbro))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2025-01-14&to=2025-06-13&type=c))

[@hoxbro](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Ahoxbro+updated%3A2025-01-14..2025-06-13&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2025-01-14..2025-06-13&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 3.0.4

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.3...2000a5eda8720cf0088ccc496ca0a0362cd8bee0))

### Merged PRs

- Ensure Widget Manager can be defined asynchronously [#130](https://github.com/holoviz/pyviz_comms/pull/130) ([@philippjfr](https://github.com/philippjfr))
- Add environment variable at startup [#123](https://github.com/holoviz/pyviz_comms/pull/123) ([@hoxbro](https://github.com/hoxbro))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2024-08-01&to=2025-01-14&type=c))

[@hoxbro](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Ahoxbro+updated%3A2024-08-01..2025-01-14&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2024-08-01..2025-01-14&type=Issues)

## 3.0.3

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.2...0149ff082df9cf0f600cf14563c45f83c1894366))

### Merged PRs

- Reformat `package.json` to 2-space indent [#128](https://github.com/holoviz/pyviz_comms/pull/128) ([@krassowski](https://github.com/krassowski))
- Fix panel preview rendering on JupyterHub 4.1+ [#125](https://github.com/holoviz/pyviz_comms/pull/125) ([@krassowski](https://github.com/krassowski))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2024-03-22&to=2024-08-01&type=c))

[@krassowski](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Akrassowski+updated%3A2024-03-22..2024-08-01&type=Issues)

## 3.0.2

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.1...ec9873fba879d232ea7072d0bead9c6f48686296))

### Merged PRs

- Ensure save handler gracefully handles undefined layout data [#121](https://github.com/holoviz/pyviz_comms/pull/121) ([@philippjfr](https://github.com/philippjfr))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2024-01-15&to=2024-03-21&type=c))

[@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2024-01-15..2024-03-21&type=Issues)

## 3.0.1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.0...e7ed26085532186997707a5debc4ddd6a9be6685))

### Merged PRs

- Add save handler for Panel Layout Builder [#120](https://github.com/holoviz/pyviz_comms/pull/120) ([@philippjfr](https://github.com/philippjfr))
- Publish again to the `pyviz` channel [#117](https://github.com/holoviz/pyviz_comms/pull/117) ([@maximlt](https://github.com/maximlt))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-08-16&to=2024-01-15&type=c))

[@maximlt](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Amaximlt+updated%3A2023-08-16..2024-01-15&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-08-16..2024-01-15&type=Issues)

## 3.0.0

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)

## 3.0.0a3

No merged PRs

## 3.0.0a2

No merged PRs

## 3.0.0a1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)

==> pyviz_comms-3.0.6.tar.gz: pyviz_comms-3.0.6/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 3.0.6

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.5...428c12aa806be9c9337b7dde00c3f7d46597443d))

### Merged PRs

- Improve re-connect behavior [#139](https://github.com/holoviz/pyviz_comms/pull/139) ([@philippjfr](https://github.com/philippjfr))
- Import `get_ipython` to avoid `NameError` [#138](https://github.com/holoviz/pyviz_comms/pull/138) ([@basnijholt](https://github.com/basnijholt))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2025-06-13&to=2025-06-16&type=c))

[@basnijholt](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Abasnijholt+updated%3A2025-06-13..2025-06-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2025-06-13..2025-06-16&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 3.0.5

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.4...f122bf716c61db4ae38a1247a6d4bc745516f94e))

### Merged PRs

- Ensure comms can reconnect on page reload [#136](https://github.com/holoviz/pyviz_comms/pull/136) ([@philippjfr](https://github.com/philippjfr))
- ci: Update Github Actions version number [#135](https://github.com/holoviz/pyviz_comms/pull/135) ([@hoxbro](https://github.com/hoxbro))
- fix: Use get_ipython for \_in_ipython check [#134](https://github.com/holoviz/pyviz_comms/pull/134) ([@hoxbro](https://github.com/hoxbro))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2025-01-14&to=2025-06-13&type=c))

[@hoxbro](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Ahoxbro+updated%3A2025-01-14..2025-06-13&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2025-01-14..2025-06-13&type=Issues)

## 3.0.4

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.3...2000a5eda8720cf0088ccc496ca0a0362cd8bee0))

### Merged PRs

- Ensure Widget Manager can be defined asynchronously [#130](https://github.com/holoviz/pyviz_comms/pull/130) ([@philippjfr](https://github.com/philippjfr))
- Add environment variable at startup [#123](https://github.com/holoviz/pyviz_comms/pull/123) ([@hoxbro](https://github.com/hoxbro))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2024-08-01&to=2025-01-14&type=c))

[@hoxbro](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Ahoxbro+updated%3A2024-08-01..2025-01-14&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2024-08-01..2025-01-14&type=Issues)

## 3.0.3

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.2...0149ff082df9cf0f600cf14563c45f83c1894366))

### Merged PRs

- Reformat `package.json` to 2-space indent [#128](https://github.com/holoviz/pyviz_comms/pull/128) ([@krassowski](https://github.com/krassowski))
- Fix panel preview rendering on JupyterHub 4.1+ [#125](https://github.com/holoviz/pyviz_comms/pull/125) ([@krassowski](https://github.com/krassowski))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2024-03-22&to=2024-08-01&type=c))

[@krassowski](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Akrassowski+updated%3A2024-03-22..2024-08-01&type=Issues)

## 3.0.2

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.1...ec9873fba879d232ea7072d0bead9c6f48686296))

### Merged PRs

- Ensure save handler gracefully handles undefined layout data [#121](https://github.com/holoviz/pyviz_comms/pull/121) ([@philippjfr](https://github.com/philippjfr))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2024-01-15&to=2024-03-21&type=c))

[@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2024-01-15..2024-03-21&type=Issues)

## 3.0.1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.0...e7ed26085532186997707a5debc4ddd6a9be6685))

### Merged PRs

- Add save handler for Panel Layout Builder [#120](https://github.com/holoviz/pyviz_comms/pull/120) ([@philippjfr](https://github.com/philippjfr))
- Publish again to the `pyviz` channel [#117](https://github.com/holoviz/pyviz_comms/pull/117) ([@maximlt](https://github.com/maximlt))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-08-16&to=2024-01-15&type=c))

[@maximlt](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Amaximlt+updated%3A2023-08-16..2024-01-15&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-08-16..2024-01-15&type=Issues)

## 3.0.0

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)

## 3.0.0a3

No merged PRs

## 3.0.0a2

No merged PRs

## 3.0.0a1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)
